#!/usr/bin/env perl

# (c) 2002 Ed Green, UC Regents
# means test

use Getopt::Std;
use strict;

use vars qw( $opt_o $opt_t $opt_s $opt_m $opt_n );

MAIN : {
    &init();
    my ( $mu1, $s1 ) = &readCd( $opt_o );
    my ( $mu2, $s2 ) = &readCd( $opt_t );
    
    if ( $opt_m ) {
	$mu1 = $opt_m;
    }
    if ( $opt_n ) {
	$mu2 = $opt_n;
    }

    my $z = ( $mu1 - $mu2 ) / 
	(sqrt ( (($s1*$s1)/($opt_s - 1)) + (($s2*$s2)/($opt_s - 1)) ) );
    
    print( "Z score = $z\n" );

}

sub readCd {
    my $fn = shift;
    my ( $l, $s, $mu );
    open( IN, $fn ) or die( "$fn : $!" );
    
    while ( $l = <IN> ) {
	if ( $l =~ /Expected.+EPQ is\s+(\d+\.\d+)/ ) {
	    $mu = $1;
	}
	if ( $l =~ /dard error.+EPQ is\s+(\d+\.\d+)/ ) {
	    $s = $1;
	    close( IN );
	    return ( $mu, $s );
	}
    }
    close( IN );
}
# cd_0.01 data in ./ at 0.01
# Expected value for coverage at 0.01 EPQ is  0.341584714600528

# Stdandard error for coverage at 0.01 EPQ is 0.0211133129594526


sub init {
    getopts( 'o:t:s:m:n:' );
    unless ( $opt_o && $opt_t && $opt_s ) {
	print( "meansTest.pl - Does a means test on the means of two\n" );
	print( "bootstrap distributions.\n" );
	print( "OPTIONS:\n" );
	print( "-o [ input covDist.pl file #1 ]\n" );
	print( "-t [ input covDist.pl file #2 ]\n" );
	print( "-s [ size of sample ]\n" );
	print( "-m [ override the mu for input one with this value ]\n" );
	print( "-n [ override the mu for input two with this value ]\n" );
	exit( 0 );
    }
    
}


